@@ -1,16 +1,18 @@
 #! /usr/bin/python3.6
 
+from pathlib import Path
+
+from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.product_structure_interfaces.analyze import Analyze
 from pycatia.base_interfaces.move import Move
-from pycatia.base_interfaces.position import Position
-from .enumeration_types import cat_file_types
-from .enumeration_types import cat_work_mode_types
-from .enumeration_types import cat_rep_types
+from pycatia.in_interfaces.position import Position
+from pycatia.enumeration.enumeration_types import cat_file_type
+from pycatia.enumeration.enumeration_types import cat_work_mode_type
+from pycatia.enumeration.enumeration_types import cat_rep_type
 
 
-class Product:
-
-    def __init__(self, product):
+class Product(AnyObject):
+    def __init__(self, com_object):
         """
 
         .. note::
@@ -29,10 +31,11 @@ class Product:
             reference objects only, and some others are for components only. This is clearly stated
             for each property or method concerned.
 
-        :param product: Product COM object
+        :param com_object: Product COM object
         """
 
-        self.product = product
+        super().__init__(com_object)
+        self.product = com_object
 
     @property
     def analyze(self):
@@ -41,7 +44,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Analyze
-                | o Property Analyze(    ) As Analyze
+                | o Property Analyze() As Analyze
                 |
                 | Returns the Analyze object associated to the current product.
                 | Example:    This example retrieves in EngineAnalysis the Analyze
@@ -49,12 +52,10 @@ class Product:
                 | EngineAnalysis = Engine.Analyze
 
 
-                | Parameters:
-
         :return: analyze object
         """
 
-        return Analyze(self.product)
+        return Analyze(self.product.Analyze)
 
     @property
     def definition(self):
@@ -144,15 +145,6 @@ class Product:
         """
         self.product.DescriptionRef = description_reference
 
-    @property
-    def file_name(self):
-        """
-
-        :return: str
-        """
-
-        return self.product.ReferenceProduct.Parent.Name
-
     @property
     def move(self):
         """
@@ -160,7 +152,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Move
-                | o Property Move(    ) As Move
+                | o Property Move() As Move
                 |
                 | Returns the product's move object. The move object is aggregated by
                 | the product object and itself aggregates a movable object to which you
@@ -170,21 +162,44 @@ class Product:
                 | Engine product.  Dim EngineMoveObject As Move Set EngineMoveObject =
                 | Engine.Move
 
-
-                | Parameters:
-
-
         """
         return Move(self.product)
 
     @property
-    def name(self):
+    def file_name(self):
         """
 
         :return: str()
         """
 
-        return self.product.Name
+        return self.product.ReferenceProduct.Parent.Name
+
+    @property
+    def full_name(self):
+        """
+
+        :return: str()
+        """
+
+        return self.product.ReferenceProduct.Parent.FullName
+
+    def path(self):
+        """
+       
+        Returns the pathlib.Path() object of the document fullname.
+
+        example e://users//psr//Parts//MyNiceProduct.CATProduct
+        >>> Product.path().name
+        >>> # MyNiceProduct.CATProduct
+        >>> Product.path().parent
+        >>> # e://users//psr//Parts//
+        >>> Product.path().suffix
+        >>> # .CATProduct
+
+        :return: Path()
+        """
+
+        return Path(self.full_name)
 
     @property
     def nomenclature(self):
@@ -223,7 +238,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Parameters
-                | o Property Parameters(    ) As Parameters
+                | o Property Parameters() As Parameters
                 |
                 | Returns the collection object containing the product parameters. All
                 | the parameters that are aggregated in the different objects of the
@@ -232,10 +247,6 @@ class Product:
                 | product from the productDoc product document:  Set productRoot =
                 | productDoc.Product Set params = productRoot.Parameters
 
-
-                | Parameters:
-
-
         """
         # todo: not implemented yet.
         return self.product.Parameters
@@ -276,7 +287,7 @@ class Product:
              CAA V5 Visual Basic help
 
                  | Position
-                 | o Property Position(    ) As Position
+                 | o Property Position() As Position
                  |
                  | Returns the product's position object. The position object is the
                  | object aggregated by the product object that holds the position of the
@@ -285,9 +296,6 @@ class Product:
                  | EnginePositionObject As Position Set EnginePositionObject =
                  | Engine.Position
 
-
-                 | Parameters:
-
          """
 
         return Position(self.product)
@@ -299,17 +307,13 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Products
-                | o Property Products(    ) As Products
+                | o Property Products() As Products
                 |
                 | Returns the collection of products contained in the current product.
                 | Example:    This example retrieves in EngineChildren the collection of
                 | products contained in the Engine product.  Dim EngineChildren As
                 | Products Set EngineChildren = Engine.Products
 
-
-                | Parameters:
-
-
         """
         return self.product.Products
 
@@ -320,14 +324,10 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Publications
-                | o Property Publications(    ) As Publications
+                | o Property Publications() As Publications
                 |
                 | Returns the collection of publications managed by the product.
 
-
-                | Parameters:
-
-
         """
         return self.product.Publications
 
@@ -338,14 +338,10 @@ class Product:
             CAA V5 Visual Basic help
 
                 | ReferenceProduct
-                | o Property ReferenceProduct(    ) As Product
+                | o Property ReferenceProduct() As Product
                 |
                 | Returns the Reference Product of this instance.
 
-
-                | Parameters:
-
-
         """
         return self.product.ReferenceProduct
 
@@ -356,7 +352,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Relations
-                | o Property Relations(    ) As Relations
+                | o Property Relations() As Relations
                 |
                 | Returns the collection object containing the product relations. All
                 | the relations that are used to valuate the parameters of the product
@@ -365,10 +361,6 @@ class Product:
                 | productDoc product document:  Set productRoot = productDoc.Product Set
                 | rels = productRoot.Relations
 
-
-                | Parameters:
-
-
         """
         return self.product.Relations
 
@@ -407,7 +399,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Source
-                | o Property Source(    ) As CatProductSource
+                | o Property Source() As CatProductSource
                 |
                 | Returns or sets the product's source. Source is valid for reference
                 | products only.  According to the STEP AP203, the source is the "design
@@ -418,10 +410,6 @@ class Product:
                 | example sets the source for the Engine product to catProductMade.
                 | Engine.Source(catProductMade)
 
-
-                | Parameters:
-
-
         """
         return self.product.Source
 
@@ -432,7 +420,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | UserRefProperties
-                | o Property UserRefProperties(    ) As Parameters
+                | o Property UserRefProperties() As Parameters
                 |
                 | Returns the collection object containing the product properties. All
                 | the user defined properties that are created in the reference product
@@ -442,10 +430,6 @@ class Product:
                 | productDoc product document:  Set productRoot = productDoc.Product Set
                 | UserProps = productRoot.UserRefProperties
 
-
-                | Parameters:
-
-
         """
         return self.product.UserRefProperties
 
@@ -456,18 +440,20 @@ class Product:
         :return: str
         """
 
-        return ('(Product) Attributes... \n'
-                f'File Name:             {self.file_name}\n'
-                f'Name:                  {self.name}\n'
-                f'Part Number:           {self.part_number}\n'
-                f'Revision:              {self.revision}\n'
-                f'Definition:            {self.definition}\n'
-                f'Nomenclature:          {self.nomenclature}\n'
-                f'Description Instance:  {self.description_instance}\n'
-                f'Description Reference: {self.description_reference}\n'
-                f'Reference:             {self.reference_product}\n'
-                f'Is CATProduct:         {self.is_catproduct()}\n'
-                f'Is CATPart:            {self.is_catpart()}')
+        return (
+            "(Product) Attributes... \n"
+            f"File Name:             {self.file_name}\n"
+            f"Name:                  {self.name}\n"
+            f"Part Number:           {self.part_number}\n"
+            f"Revision:              {self.revision}\n"
+            f"Definition:            {self.definition}\n"
+            f"Nomenclature:          {self.nomenclature}\n"
+            f"Description Instance:  {self.description_instance}\n"
+            f"Description Reference: {self.description_reference}\n"
+            f"Reference:             {self.reference_product}\n"
+            f"Is CATProduct:         {self.is_catproduct()}\n"
+            f"Is CATPart:            {self.is_catpart()}"
+        )
 
     def activate_default_shape(self):
         """
@@ -475,14 +461,10 @@ class Product:
             CAA V5 Visual Basic help
 
                 | ActivateDefaultShape
-                | o Sub ActivateDefaultShape(    )
+                | o Sub ActivateDefaultShape()
                 |
                 | Activate default shape.
 
-
-                | Parameters:
-
-
         """
         return self.product.ActivateDefaultShape()
 
@@ -495,8 +477,7 @@ class Product:
                 | o Sub ActivateShape(    CATBSTR    ShapeName)
                 |
                 | Activate one shape.
-
-
+                |
                 | Parameters:
                 | ShapeName
                 |            The name of the shape.
@@ -515,6 +496,7 @@ class Product:
         :param products: self.get_products()
         """
 
+        # noinspection PyShadowingNames
         def loop_d_loop(products):
 
             for product in products:
@@ -546,22 +528,21 @@ class Product:
                 | Parameters:
                 | iShapePathName
                 |    The path name where the master shape representation can be found
-
-
+                |
                 | Examples:
                 |
                 | This example adds the e:/Models/Engine.model as
                 | the master shape representation to the Engine product.
                 |
                 | Engine.AddMasterShapeRepresentation("e:/Models/Engine.model")
-                |
-                |
-                |
+
         """
         # todo: not yet implemented
         return self.product.AddMasterShapeRepresentation(i_shape_path_name)
 
-    def add_shape_representation(self, i_shape_path_name, i_shape_name, i_rep_behavior, i_context):
+    def add_shape_representation(
+            self, i_shape_path_name, i_shape_name, i_rep_behavior, i_context
+    ):
         """
         .. note::
             CAA V5 Visual Basic help
@@ -580,38 +561,32 @@ class Product:
                 | can also be added within a context or not. A representation on a
                 | product is optional, but many representation with  different behavior
                 | (or the same) is supported
-
-
+                |
                 | Parameters:
                 | iShapePathName
                 |    The path name where the representation can be found
-                |
                 |  iShapeName
                 |    The name that is given to the representation
                 |    This name is a user free choice
-                |
                 |  iRepBehavior
                 |    The behavior of the added representation.
                 |    It can take the values catRep3D if the representation is a 3D one,
                 |    catRep2D if the representation is a 2D one,
                 |    or catRepText if the representation is a text one.
-                |
                 |  iContext
                 |    A condition to specify if the added representation can be
                 |    displayed with the representation of other products.
-
-
-                | Examples:
                 |
+                | Examples:
                 | This example adds the e:/Models/Engine.model as
                 | a 3D representation to the Engine product within an assembly context.
-                |
                 | Engine.AddShapeRepresentation("e:/Models/Engine.model","MyShape",catRep3D,TRUE)
-                |
 
         """
         # todo: not yet implemented
-        return self.product.AddShapeRepresentation(i_shape_path_name, i_shape_name, i_rep_behavior, i_context)
+        return self.product.AddShapeRepresentation(
+            i_shape_path_name, i_shape_name, i_rep_behavior, i_context
+        )
 
     def apply_work_mode(self, new_mode):
         """
@@ -626,15 +601,14 @@ class Product:
                 | o Sub ApplyWorkMode(    CatWorkModeType    newMode)
                 |
                 | Applies a new working mode.
-
-
+                |
                 | Parameters:
                 | newMode
                 |            The new working mode.
 
         :param str new_mode:
         """
-        return self.product.ApplyWorkMode(cat_work_mode_types[new_mode])
+        return self.product.ApplyWorkMode(cat_work_mode_type.index(new_mode))
 
     def connections(self, i_connections_type):
         """
@@ -650,10 +624,6 @@ class Product:
                 | constraint collection for the Engine product.  Dim EngineConstraints
                 | As Collection Set EngineConstraints = Engine.Constraints
 
-
-                | Parameters:
-
-
         """
         return self.product.Connections(i_connections_type)
 
@@ -669,8 +639,7 @@ class Product:
                 | stand for any geometrical object. Creating references is necessary for
                 | adding constraints between two components using Brep elements of the
                 | representations of these components.
-
-
+                |
                 | Parameters:
                 | iLabel
                 |    The path of the Brep element to use in the constraint.
@@ -680,13 +649,10 @@ class Product:
                 |    Components are separated using "/", and the product path is separated
                 |    from the Brep using "/!". For separating parameter from product path use "/".
                 |
-                |
                 |  Returns:
                 |   The created reference
-
-
-                | Examples:
                 |
+                | Examples:
                 | This example creates a reference from the path of a Brep element
                 | in the Prod2 product located below the Root root
                 | product. The face is located in the Pad.1 pad and limited by the
@@ -694,30 +660,24 @@ class Product:
                 |
                 | Dim Ref As Reference
                 | Ref = Prod2.CreateReferenceFromName("Root/Prod2/!Face:(Brp:(Pad.1:0(Brp:(Circle.1))):None())")
-                |
-                |
-                |
+
         """
         return self.product.CreateReferenceFromName(i_label)
 
-    def desactivate_default_shape(self):
+    def deactivate_default_shape(self):
         """
         .. note::
             CAA V5 Visual Basic help
 
                 | DesactivateDefaultShape
-                | o Sub DesactivateDefaultShape(    )
+                | o Sub DesactivateDefaultShape()
                 |
                 | Deactivate default shape.
 
-
-                | Parameters:
-
-
         """
         return self.product.DesactivateDefaultShape()
 
-    def desactivate_shape(self, shape_name):
+    def deactivate_shape(self, shape_name):
         """
         .. note::
             CAA V5 Visual Basic help
@@ -726,13 +686,11 @@ class Product:
                 | o Sub DesactivateShape(    CATBSTR    ShapeName)
                 |
                 | Deactivate one shape.
-
-
+                |
                 | Parameters:
                 | ShapeName
                 |            The name of the shape.
 
-
         """
         return self.product.DesactivateShape(shape_name)
 
@@ -752,8 +710,7 @@ class Product:
                 | Extracts the product's contents as a bill of materials (BOM). The bill
                 | of material displays, for every sub-assembly in the product, the one
                 | level depth components and some of their properties.
-
-
+                |
                 | Parameters:
                 | iFileType
                 |    Set this parameter to catFileTypeHTML to save to the html format.
@@ -767,7 +724,7 @@ class Product:
 
 
         """
-        return self.product.ExtractBOM(cat_file_types[i_file_type], i_file)
+        return self.product.ExtractBOM(cat_file_type[i_file_type], i_file)
 
     def get_active_shape_name(self):
         """
@@ -775,15 +732,11 @@ class Product:
             CAA V5 Visual Basic help
 
                 | GetActiveShapeName
-                | o Func GetActiveShapeName(    ) As CATBSTR
+                | o Func GetActiveShapeName() As CATBSTR
                 |
                 | Returns the name of the active shape.  Returns:  oShapeName
                 | The name of the active shape.
 
-
-                | Parameters:
-
-
         """
         return self.product.GetActiveShapeName()
 
@@ -799,13 +752,23 @@ class Product:
                 | of the names  The tab olistshape has to be allocated with a size given
                 | by GetNumberOfShapes.
 
-
-                | Parameters:
-
-
         """
         return self.product.GetAllShapesNames(olistshape)
 
+    def count_children(self):
+        """
+
+       :return: int()
+       """
+
+        return self.product.Products.Count
+
+    def get_child(self, index):
+        """
+        :return: Product()
+        """
+        return Product(self.product.Products.Item(index + 1))
+
     def get_children(self):
         """
 
@@ -827,15 +790,11 @@ class Product:
             CAA V5 Visual Basic help
 
                 | GetDefaultShapeName
-                | o Func GetDefaultShapeName(    ) As CATBSTR
+                | o Func GetDefaultShapeName() As CATBSTR
                 |
                 | Returns the default shape.  Returns:  oShapeName           The name of
                 | the default shape.
 
-
-                | Parameters:
-
-
         """
         return self.product.GetDefaultShapeName()
 
@@ -848,14 +807,12 @@ class Product:
                 | o Func GetMasterShapeRepresentation(    boolean    iLoadIfNecessary) As CATBaseDispatch
                 |
                 | Retrieves the product's master shape representation.
-
-
+                |
                 | Parameters:
                 | iLoadIfNecessary
                 |    Parameter to set to True if the master shape representation
                 |    should be loaded to determine if it exists, or to False otherwise.
-
-
+                |
                 | Examples:
                 |
                 | This example retrieves in MSRep the
@@ -863,9 +820,8 @@ class Product:
                 |
                 | Dim MSRep As Object
                 | Set MSRep = Engine.GetMasterShapeRepresentation(True)
-                |
-                |
-                |
+
+
         """
         return self.product.GetMasterShapeRepresentation(i_load_if_necessary)
 
@@ -875,17 +831,13 @@ class Product:
             CAA V5 Visual Basic help
 
                 | GetMasterShapeRepresentationPathName
-                | o Func GetMasterShapeRepresentationPathName(    ) As CATBSTR
+                | o Func GetMasterShapeRepresentationPathName() As CATBSTR
                 |
                 | Retrieves the product's master shape representation pathname.
                 | Example:    This example retrieves in MSRep the  Engine product's
                 | master shape representation.  Set MSRepPath =
                 | Engine.GetMasterShapeRepresentationPathName
 
-
-                | Parameters:
-
-
         """
         return self.product.GetMasterShapeRepresentationPathName()
 
@@ -895,25 +847,21 @@ class Product:
             CAA V5 Visual Basic help
 
                 | GetNumberOfShapes
-                | o Func GetNumberOfShapes(    ) As short
+                | o Func GetNumberOfShapes() As short
                 |
                 | Returns the number of Shapes  Returns:  oNbShapes           The number
                 | of Shapes.
 
-
-                | Parameters:
-
-
         """
         return self.product.GetNumberOfShapes()
 
     def get_products(self):
         """
-        Returns a list of Products().
+        Returns a list of Product().
 
-        :return: list(Proucts())
+        :return: [Product()]
         """
-        products = list()
+        products = []
 
         for i in range(0, self.product.Products.Count):
             product = Product(self.product.Products.Item(i + 1))
@@ -930,24 +878,24 @@ class Product:
                 | o Func GetShapePathName(    CATBSTR    iShapeName) As CATBSTR
                 |
                 | Returns the path name of a shape for a given shape name.
-
-
+                |
                 | Parameters:
                 | iShapeName
                 |    The name of the shape.
                 |
-                |
                 |  Returns:
                 |   oShapePathName           The path name of the shape.
 
-
         """
         return self.product.GetShapePathName(i_shape_name)
 
-    def get_shape_representation(self, i_load_if_necessary, i_shape_name, i_rep_behavior, i_context):
+    def get_shape_representation(
+            self, i_load_if_necessary, i_shape_name, i_rep_behavior, i_context
+    ):
         """
 
         i_rep_behaviour must be a string taken from KEY value of cat_rep_types
+
         .. note::
             CAA V5 Visual Basic help
 
@@ -958,27 +906,22 @@ class Product:
                 |                                   boolean    iContext) As CATBaseDispatch
                 |
                 | Retrieves the product's  representation with the given parameters.
-
-
+                |
                 | Parameters:
                 | iLoadIfNecessary
                 |    Parameter to set to True if the master shape representation
                 |    should be loaded to determine if it exists, or to False otherwise.
-                |
                 |  iShapeName
                 |    The name of the representation of the product.
-                |
                 |  iRepBehavior
                 |    The behavior of the representation.
                 |    It can take the values catRep3D if the representation is a 3D one,
                 |    catRep2D if the representation is a 2D one,
                 |    or catRepText if the representation is a text one.
-                |
                 |  iContext
                 |    A condition to specify if the representation is
                 |    displayed with the representation of other products.
-
-
+                |
                 | Examples:
                 |
                 | This example retrieves in MSRep the
@@ -986,15 +929,15 @@ class Product:
                 |
                 | Dim MSRep As Object
                 | Set MSRep = Engine.GetMasterShapeRepresentation(True,"PART",catRep3D,TRUE)
-                |
-                |
-                |
+
         """
-        return self.product.GetShapeRepresentation(i_load_if_necessary, i_shape_name, cat_rep_types[i_rep_behavior],
-                                                   i_context)
+        return self.product.GetShapeRepresentation(
+            i_load_if_necessary, i_shape_name, cat_rep_type[i_rep_behavior], i_context
+        )
 
     def get_technological_object(self, i_application_type):
         """
+
         .. note::
             CAA V5 Visual Basic help
 
@@ -1004,13 +947,11 @@ class Product:
                 | Returns the product's applicative data which type is the given
                 | parameter. The data returned can be either a collection or a simple
                 | object.
-
-
+                |
                 | Parameters:
                 | iApplicationType
                 |    The type of applicative data searched.
-
-
+                |
                 | Examples:
                 |
                 | This example retrieves the constraints for the
@@ -1018,9 +959,7 @@ class Product:
                 |
                 | Dim EngineConstraints As Collection
                 | Set EngineConstraints = Engine.GetTechnologicalObject("Constraints")
-                |
-                |
-                |
+
         """
         return self.product.GetTechnologicalObject(i_application_type)
 
@@ -1047,8 +986,7 @@ class Product:
                 |
                 | Returns whether the product has a representation of the given name
                 | with a given behavior. True if the product has such a representation.
-
-
+                |
                 | Parameters:
                 | iShapeName
                 |    The name of the representation of the product.
@@ -1062,19 +1000,18 @@ class Product:
                 |  iContext
                 |    A condition to specify if the representation is
                 |    displayed with the representation of other products.
-
-
+                |
                 | Examples:
                 |
                 | This example retrieves in HasRep whether the
                 | Engine product has a master shape representation.
                 |
                 | HasRep = Engine.HasRepresentation("PART",catRep3D,TRUE)
-                |
-                |
-                |
+
         """
-        return self.product.HasShapeRepresentation(i_shape_name, cat_rep_types[i_rep_behavior], i_context)
+        return self.product.HasShapeRepresentation(
+            i_shape_name, cat_rep_type[i_rep_behavior], i_context
+        )
 
     def is_catproduct(self):
         """
@@ -1082,7 +1019,7 @@ class Product:
         :return: bool
         """
 
-        if 'catproduct' == self.file_name.rsplit('.')[1].lower():
+        if "catproduct" == self.file_name.rsplit(".")[-1].lower():
             return True
 
         return False
@@ -1093,7 +1030,7 @@ class Product:
         :return: bool
         """
 
-        if 'catpart' == self.file_name.rsplit('.')[1].lower():
+        if "catpart" == self.file_name.rsplit(".")[-1].lower():
             return True
 
         return False
@@ -1104,7 +1041,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | RemoveMasterShapeRepresentation
-                | o Sub RemoveMasterShapeRepresentation(    )
+                | o Sub RemoveMasterShapeRepresentation()
                 |
                 | Removes the master shape representation from the product. The master
                 | shape representation is the object that gives a geometric shape and
@@ -1117,10 +1054,6 @@ class Product:
                 | removes the master shape representation of the Engine product.
                 | Engine.RemoveMasterShapeRepresentation()
 
-
-                | Parameters:
-
-
         """
         return self.product.RemoveMasterShapeRepresentation()
 
@@ -1139,8 +1072,7 @@ class Product:
                 | visualization of the product.. It can be a CATIA V4 model, a VRML
                 | file, or any other type of document that can be displayed. Note: This
                 | representation is optional.
-
-
+                |
                 | Parameters:
                 | iShapeName
                 |    The name of the representation of the product.
@@ -1154,8 +1086,7 @@ class Product:
                 |  iContext
                 |    A condition to specify if the representation is
                 |    displayed with the representation of other products.
-
-
+                |
                 | Examples:
                 |
                 | This example removes the 3D representation named "PART" of the
@@ -1163,11 +1094,11 @@ class Product:
                 |
                 | Engine.RemoveMasterShapeRepresentation
                 | ("PART",catRep3D,TRUE)
-                |
-                |
-                |
+
         """
-        return self.product.RemoveShapeRepresentation(i_shape_name, cat_rep_types[i_rep_behavior], i_context)
+        return self.product.RemoveShapeRepresentation(
+            i_shape_name, cat_rep_type[i_rep_behavior], i_context
+        )
 
     def update(self):
         """
@@ -1175,7 +1106,7 @@ class Product:
             CAA V5 Visual Basic help
 
                 | Update
-                | o Sub Update(    )
+                | o Sub Update()
                 |
                 | Updates the product. This update is performed with respect to the part
                 | making the product or to the product's representation. It takes into
@@ -1183,12 +1114,8 @@ class Product:
                 | following example updates the root product:  Dim RootProduct As
                 | Product Set Rootproduct = productDoc.Product Rootproduct.Update
 
-
-                | Parameters:
-
-
         """
         return self.product.Update()
 
     def __repr__(self):
-        return f'(Product) part_number: {self.part_number}, file_name: {self.file_name}'
+        return f'Product(name="{self.name}")'
